var PLUGIN_COMMON = 'UiCableDialogExtension';

function UiCableDialogExtension(plug, upd) {
    var plugin = plug;
    var updater = upd;
    var darkMode = true;
    
    var setting = plugin.loadSetting(PLUGIN_COMMON, 'DisplayTheme');
    darkMode = setting != 'LIGHT';
    
    
    function setTooltip(sel, tip) {
        $(sel).on('mouseover', function() {
            updater.nav_.statusTip(tip);
        });
        $(sel).on('mouseleave', function() {
            updater.nav_.statusTip("");
        });    
    };    
        
    function createMenuActions() {
        var wrap = UiWrapper.instance();
        var sma = wktnav_.findMenuAction("Setup");
        var sm = UiHelpers.action_menu(sma);
        var fa = UiHelpers.menu_first_action(sm);
        var e_act = UiHelpers.menu_insert_action(wrap, sm, fa, "Encoders/Strain Gauges...");
        e_act.loadIcon(":/qrc/Resources/loadcell.png");
        e_act.statusTip = "Opens the encoders dialog - this let's you select the primary cable engine";
        setTooltip('#ddm6', e_act.statusTip);
        e_act.triggered.connect(function() {
            encodersDialog();
        });
        var ts_act = UiHelpers.menu_insert_action(wrap, sm, fa, "Target Slack...");
        ts_act.loadIcon(":/qrc/Resources/slack.png");
        ts_act.statusTip = "Opens the target slack dialog which allows changing the target slack for cable lay";
        setTooltip('#ddm4', ts_act.statusTip);
        ts_act.triggered.connect(function() {
            targetSlackDialog();
        });
        UiHelpers.menu_insert_separator(wrap, sm, fa);
        
        var vma = wktnav_.findMenuAction("View");
        var vm = UiHelpers.action_menu(vma);            
        fa = UiHelpers.menu_first_action(vm);
        var opt_act = UiHelpers.menu_insert_action(wrap, vm, fa, "Cable Display Options...");
        opt_act.loadIcon(":/qrc/Resources/cableui.png");
        opt_act.statusTip = "Opens the cable display options dialog - this allows you to change the gauge and graph ranges";
        setTooltip('#ddm1', opt_act.statusTip);
        opt_act.triggered.connect(function() {
            optionsDialog();
        });            
        
        //fa = UiHelpers.action_menu(opt_act);
        var opt_disp = UiHelpers.menu_insert_action(wrap, vm, fa, "Cable Plugin Dark Background");
        opt_act.statusTip = "Changes the cable plugin background color";
        
        var setting = plugin.loadSetting(PLUGIN_COMMON, 'DisplayTheme');
        opt_disp.setCheckable(true);
        opt_disp.setChecked(darkMode);
        
        opt_disp.triggered.connect(function() {
            darkMode = opt_disp.isChecked();
            plugin.saveSetting(PLUGIN_COMMON, 'DisplayTheme', darkMode ? 'DARK' : 'LIGHT');
            setDisplayDarkMode(darkMode);
        });            
        UiHelpers.menu_insert_separator(wrap, vm, fa);

        
        var rma = wktnav_.findMenuAction("Route");
        var rm = UiHelpers.action_menu(rma); 
        fa = UiHelpers.menu_first_action(rm);            
        var cra = UiHelpers.menu_insert_menu(wrap, rm, fa, "Cable Route");
        UiHelpers.menu_insert_separator(wrap, rm, fa);
        var crm = UiHelpers.action_menu(cra); 
        var opt_r_man = UiHelpers.menu_insert_action(wrap, crm, null, "Manual...");
        opt_r_man.statusTip = "Opens the manual cable route dialog";
        setTooltip('#ddm2', opt_r_man.statusTip);
        var opt_r_auto = UiHelpers.menu_insert_action(wrap, crm, null, "Automatic...");
        opt_r_auto.statusTip = "Opens the automatic cable route dialog";
        setTooltip('#ddm3', opt_r_auto.statusTip);
        UiHelpers.menu_insert_separator(wrap, crm, null);
        var opt_r_dd = UiHelpers.menu_insert_action(wrap, crm, null, "Distance Deviation...");
        opt_r_dd.loadIcon(":/qrc/Resources/distdev.png");
        opt_r_dd.statusTip = "Let's you change the distance deviation method";
        setTooltip('#ddm', opt_r_dd.statusTip);
        
        var opt_r_dprev = UiHelpers.menu_insert_action(wrap, crm, null, "Previous Distances...");
        //opt_r_dprev.loadIcon(":/qrc/Resources/distdev.png");
        opt_r_dprev.statusTip = "Let's you change the cable route previous distances";
        opt_r_dprev.loadIcon("images/ruler.png");
        setTooltip('#ddm5', opt_r_dprev.statusTip);        
        
        opt_r_man.triggered.connect(function() {
            routeDialog();
        });
        opt_r_auto.triggered.connect(function() {
            autoRouteDialog();
        });
        opt_r_dd.triggered.connect(function() {
            ddCalcMethod();
        });
        opt_r_dprev.triggered.connect(function() {
            prevDistDialog();
        });
        
        setTooltip('.zmin_but', "Zoom in - decrease time range on graph");
        setTooltip('.zmout_but', "Zoom in - increase time range on graph");
        setTooltip('.cbx', "Click to toggle trend visibility");
    }
    
    function optionsDialog() {
        plugin.showDialog("cableoptionsdialog");
    }

    function encodersDialog() {
        plugin.showDialog("encoderparamsdialog");
    }

    function routeDialog() {
        plugin.showDialog("manualroutedialog");
    }

    function autoRouteDialog() {
        plugin.showDialog("autoroutedialog");
    }

    function targetSlackDialog() {
        plugin.showDialog("targetslackdialog");
    }

    function prevDistDialog() {
        plugin.showDialog("prevdistdialog");
    }

    function cumlDeviationDialog() {
        plugin.showDialog("cumdeviationdialog");
    }
    
    function ddCalcMethod() {
        var dlg = plugin.showDialog("cableoptionsdialog");
        dlg.setPage(4);
    }
        
    function inDarkMode() {
        return darkMode;
    }
        
    var ext = {
        setTooltip: setTooltip,
        createMenuActions: createMenuActions,
        optionsDialog: optionsDialog,
        encodersDialog: encodersDialog,
        routeDialog: routeDialog,
        autoRouteDialog: autoRouteDialog,
        targetSlackDialog: targetSlackDialog,
        prevDistDialog: prevDistDialog,
        cumlDeviationDialog: cumlDeviationDialog,
        ddCalcMethod: ddCalcMethod,
        inDarkMode: inDarkMode
    };
    
    return ext;
}