
var slice = Array.prototype.slice;

/**
   * Binds a function to an object. The returned function will always use the
   * passed in {@code obj} as {@code this}.
   *
   * Example:
   *
   *   g = bind(f, obj, a, b)
   *   g(c, d) // will do f.call(obj, a, b, c, d)
   *
   * @param {Function} f The function to bind the object to
   * @param {Object} obj The object that should act as this when the function
   *     is called
   * @param {*} var_args Rest arguments that will be used as the initial
   *     arguments when the function is called
   * @return {Function} A new function that has bound this
*/
function bind(f, obj, var_args) {
	var a = slice.call(arguments, 2);
    	return function() {
      		return f.apply(obj, a.concat(slice.call(arguments)));
	};
}


function start() {
	with (this) {
		singlerequest = false;
		requestData();
	}
}
 
function stop() {
	with (this) {
		singlerequest = true;
	}
}

function makeRequest() {
	with (this) {
		singlerequest = true;
		requestData();
	}
}
 
function setList(var_list) {
	with (this) {
		varlist = var_list;
	}
}

function initUpdater() {
	with (this) {
		try {
			if (nav_ == null) {
				if (typeof wktnav_ === 'object') {
					nav_ = wktnav_;
				}
				else if (typeof cefnav_ === 'object') {
					nav_ = cefnav_.iface;
				}
				else {
					nav_ = new ActiveXObject("navproxy.NavigatorProxy");
					nav_.ConnectApp("");
				}
			}
			return true;
		}
		catch (error) {

			alert("Error creating navproxy.NavigatorProxy");
		}

	}
	return false;
}

function requestData() {
	with (this) {
		if (init()) {
			beginCycle();
		}
	}
}


function beginCycle() {
	with (this) {
		fetchAgain();
	}
}


function fetchAgain() {
	with (this) {

        	var sQuery = "";
		var i;
		var vals;
		var n = 0;
        	for (i = 0; i < varlist.length; i++) {
			if (i > 0) {
				sQuery += "\n";
			}
			sQuery += varlist[i];
			n++;
		}
		if (n) {
			sQuery += "\nwebclient=embedhost";
			vals = nav_.GetVariableValues(sQuery);		
			updatePageData(vals);
		}
	}
}

function updateElement_IE(elementName, elementValue) {
	var elem = document.getElementById(elementName);
	if (elem) {
		so_clearInnerHTML(elem);
		elem.innerHTML = elementValue;
	}
}


function updateElement(elementName, elementValue) {
	var elem;

	try {
		elem = document.getElementById(elementName);
		//so_clearInnerHTML(elem);
        if (elem.innerHTML != elementValue) {
            elem.innerHTML = elementValue;
        }
		
	}
	catch (error) {
			
		elem = document[elementName];
		try {
			elem.innerHTML = elementValue;
		}
		catch (error) {
		}
		
			
	}
}


function updateElementText_IE(elementName, elementValue) {
	var elem = document[elementName];

	if (elem) {
		elem.innerText = elementValue;
	}
}

function so_clearInnerHTML(obj) {
	while(obj.firstChild) obj.removeChild(obj.firstChild);
}


function valuesReturned(valList) {
}


function updatePageData(vals) {
	with (this) {
		var sVar;
		var sVal;
		var i;
		
		var valList = vals.split("\n");
  		var n = valList.length;
		if (varlist.length < n) {
			n = varlist.length;
		}

		for (i = 0; i < n; i++) {
			sVal = valList[i];
//			sVal = unescape(sVal);
			if (sVal.length > 0) {
				if (sVal.charAt(sVal.length - 1) == "\r") {
					sVal = sVal.slice(0, sVal.length - 1);
				}
			}
			valList[i] = sVal;
		}
		valuesReturned(valList);

		for (i = 0; i < n; i++) {
			updateElement(varlist[i], valList[i]);
		}

		if (!singlerequest) {
			setTimeout(bind(this.requestData,this), interval_ms);
		}
	}
}


function AxVarUpdater(varlist) {
	this.varlist = varlist;

	this.requestData                = requestData;
	this.beginCycle                 = beginCycle;
	this.fetchAgain                 = fetchAgain;
	this.updateElement              = updateElement;
	this.updatePageData             = updatePageData;
	this.valuesReturned             = valuesReturned;
	this.start                      = start;
	this.stop                       = stop;
	this.makeRequest                = makeRequest;
	this.setList                    = setList;
	this.init                       = initUpdater;

	this.singlerequest = false;
	this.nav_ = null;
	this.interval_ms = 400;
}


function varArrayIndexOf(list, name) {
	var i;
	for (i = 0; i < list.length; i++) {
		if (list[i] == name) {
			return i;
		}
	}
	return -1;
}

function mergeVarlist(list1, list2) {
	var list = list1;
	var i;
	for (i = 0; i < list2.length; i++) {
		if (varArrayIndexOf(list, list2[i]) < 0) {
			list.push(list2[i]);
		}
	}
	return list;			
}
